---
title: "Getting Started"
description: Getting started guide for Kodit.
weight: 1
next: /kodit/getting-started/installation
---

Kodit is an MCP server that indexes codebases. As such, it can be run locally on your
laptop, or remotely on a server.

## Hosted Kodit (Free, No Install)

This is the fastest way to try Kodit.

[Helix.ML](https://helix.ml) provides a free hosted version of Kodit so you can
integrate the power of Kodit immediately. To give this a spin, skip to the [integration
with coding assistants](./integration/index.md).

More information about the hosted service is available in the [hosted Kodit documentation](../reference/hosted-kodit/index.md).

## Private Kodit

This is the most powerful way to use Kodit.

Kodit was designed to be private first, so you or your organization can index your own private
repositories. To do this, please [install kodit first](./installation/index.md), and then
[index your repositories](./quick-start/index.md).

<!--more-->

{{< default-section-cards-list >}}
